pub enum Reference {
Proc(ProcId),
Actor(ActorId),
Port(PortId),
}Expand description
A universal reference to hierarchical identifiers in Hyperactor.
References implement a concrete syntax which can be parsed via
FromStr. They are of the form:
addr,proc_name,addr,proc_name,actor_name[pid],addr,proc_name,actor_name[pid][port]
Reference also implements a total ordering, so that references are ordered lexicographically with the hierarchy implied by proc, actor. This allows reference ordering to be used to implement prefix based routing.
Variants
Proc(ProcId)
A reference to a proc.
Actor(ActorId)
A reference to an actor.
Port(PortId)
A reference to a port.
Implementations
Sourceimpl Reference
impl Reference
Sourcepub fn as_proc_mut(&mut self) -> Option<&mut ProcId>
pub fn as_proc_mut(&mut self) -> Option<&mut ProcId>
Optionally returns mutable references to the inner fields if this is a Reference::Proc, otherwise None
Sourcepub fn as_proc(&self) -> Option<&ProcId>
pub fn as_proc(&self) -> Option<&ProcId>
Optionally returns references to the inner fields if this is a Reference::Proc, otherwise None
Sourcepub fn into_proc(self) -> Result<ProcId, Self>
pub fn into_proc(self) -> Result<ProcId, Self>
Returns the inner fields if this is a Reference::Proc, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_actor_mut(&mut self) -> Option<&mut ActorId>
pub fn as_actor_mut(&mut self) -> Option<&mut ActorId>
Optionally returns mutable references to the inner fields if this is a Reference::Actor, otherwise None
Sourcepub fn as_actor(&self) -> Option<&ActorId>
pub fn as_actor(&self) -> Option<&ActorId>
Optionally returns references to the inner fields if this is a Reference::Actor, otherwise None
Sourcepub fn into_actor(self) -> Result<ActorId, Self>
pub fn into_actor(self) -> Result<ActorId, Self>
Returns the inner fields if this is a Reference::Actor, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_port_mut(&mut self) -> Option<&mut PortId>
pub fn as_port_mut(&mut self) -> Option<&mut PortId>
Optionally returns mutable references to the inner fields if this is a Reference::Port, otherwise None
Sourceimpl Reference
impl Reference
Sourcepub fn is_prefix_of(&self, other: &Reference) -> bool
pub fn is_prefix_of(&self, other: &Reference) -> bool
Tells whether this reference is a prefix of the provided reference.
Sourcepub fn kind(&self) -> ReferenceKind
pub fn kind(&self) -> ReferenceKind
Returns the kind of the reference.