pub struct OncePortRef<M> { /* private fields */ }Expand description
A remote reference to a [OncePort]. References are serializable
and may be passed to remote actors, which can then use it to send
a message to this port.
Implementations
Sourceimpl<M: RemoteMessage> OncePortRef<M>
impl<M: RemoteMessage> OncePortRef<M>
Sourcepub fn attest_reducible(
port_id: PortId,
reducer_spec: Option<ReducerSpec>,
) -> Self
pub fn attest_reducible( port_id: PortId, reducer_spec: Option<ReducerSpec>, ) -> Self
The caller attests that the provided PortId can be converted to a reachable, typed once port reference.
Sourcepub fn reducer_spec(&self) -> &Option<ReducerSpec>
pub fn reducer_spec(&self) -> &Option<ReducerSpec>
The typehash of this port’s reducer, if any.
Sourcepub fn into_port_id(self) -> PortId
pub fn into_port_id(self) -> PortId
Convert this PortRef into its corresponding port id.
Sourcepub fn send(self, cx: &impl Actor, message: M) -> Result<(), MailboxSenderError>
pub fn send(self, cx: &impl Actor, message: M) -> Result<(), MailboxSenderError>
Send a message to this port, provided a sending capability, such as
[crate::actor::Instance].
Sourcepub fn send_with_headers(
self,
cx: &impl Actor,
headers: Flattrs,
message: M,
) -> Result<(), MailboxSenderError>
pub fn send_with_headers( self, cx: &impl Actor, headers: Flattrs, message: M, ) -> Result<(), MailboxSenderError>
Send a message to this port, provided a sending capability, such as
[crate::actor::Instance]. Additional context can be provided in the form of headers.
Sourcepub fn get_return_undeliverable(&self) -> bool
pub fn get_return_undeliverable(&self) -> bool
Get whether or not messages sent to this port that are undeliverable should be returned to the sender.
Sourcepub fn return_undeliverable(&mut self, return_undeliverable: bool)
pub fn return_undeliverable(&mut self, return_undeliverable: bool)
Set whether or not messages sent to this port that are undeliverable should be returned to the sender.