pub struct PortId(/* private fields */);Expand description
Port ids identify [crate::mailbox::Port]s of an actor.
TODO: consider moving [crate::mailbox::Port] to PortRef in this
module for consistency with actors,
Implementations
Sourceimpl PortId
impl PortId
Sourcepub fn into_actor_id(self) -> ActorId
pub fn into_actor_id(self) -> ActorId
Convert this port ID into an actor ID.
Sourcepub fn send(&self, cx: &impl Actor, serialized: Any)
pub fn send(&self, cx: &impl Actor, serialized: Any)
Send a serialized message to this port, provided a sending capability,
such as [crate::actor::Instance]. It is the sender’s responsibility
to ensure that the provided message is well-typed.
Sourcepub fn send_with_headers(
&self,
cx: &impl Actor,
serialized: Any,
headers: Flattrs,
)
pub fn send_with_headers( &self, cx: &impl Actor, serialized: Any, headers: Flattrs, )
Send a serialized message to this port, provided a sending capability,
such as [crate::actor::Instance], with additional context provided by headers.
It is the sender’s responsibility to ensure that the provided message is well-typed.
Sourcepub fn split(
&self,
cx: &impl Actor,
reducer_spec: Option<ReducerSpec>,
reducer_mode: ReducerMode,
return_undeliverable: bool,
) -> Result<PortId>
pub fn split( &self, cx: &impl Actor, reducer_spec: Option<ReducerSpec>, reducer_mode: ReducerMode, return_undeliverable: bool, ) -> Result<PortId>
Split this port, returning a new port that relays messages to the port through a local proxy, which may coalesce messages.